@@ -212,7 +212,7 @@ bool SaveConfig(std::list<ConfigPlugin*>& plugins)
   return res;
 }
 
-bool LoadData()
+bool LoadData(std::list<ConfigPlugin*>& plugins)
 {
   Lum::Config::Node      *top;
   Lum::Config::ErrorList errors;
@@ -321,6 +321,10 @@ bool LoadData()
 
   delete top;
 
+  for (std::list<ConfigPlugin*>::iterator iter=plugins.begin(); iter!=plugins.end(); ++iter) {
+    (*iter)->LoadData();
+  }
+
   return true;
 }
 
