@@ -120,12 +120,13 @@ extern Lum::Model::SizeTRef calcTrigoMode;
 class ConfigPlugin
 {
 public:
+  virtual void LoadData() = 0;
   virtual void LoadConfig(Lum::Config::Node *top) = 0;
   virtual void StoreConfig(Lum::Config::Node *top) = 0;
 };
 
 
-extern bool LoadData();
+extern bool LoadData(std::list<ConfigPlugin*>& plugins);
 
 extern bool LoadConfig(std::list<ConfigPlugin*>& plugins);
 extern bool SaveConfig(std::list<ConfigPlugin*>& plugins);
