@@ -35,7 +35,7 @@
 
 #define LEADING_PAGES 1
 #define TRAILING_PAGES 1
-
+#include <iostream>
 void ListCategories(const std::wstring& category, std::vector<std::wstring>& subs)
 {
   size_t start,pos;
@@ -519,11 +519,12 @@ void FormulaCalc::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& ms
   }
 }
 
-void FormulaCalc::LoadConfig(Lum::Config::Node* /*top*/)
+void FormulaCalc::LoadData()
 {
   std::set<std::wstring> categories;
 
   for (size_t i=0; i<formulas.size(); i++) {
+    std::cout << "Formula " << i << std::endl;
     std::vector<std::wstring> subs;
 
     ListCategories(formulas[i]->GetCategory(),subs);
@@ -546,6 +547,11 @@ void FormulaCalc::LoadConfig(Lum::Config::Node* /*top*/)
   category->Set(1);
 }
 
+void FormulaCalc::LoadConfig(Lum::Config::Node* /*top*/)
+{
+  // no code
+}
+
 void FormulaCalc::StoreConfig(Lum::Config::Node *top)
 {
   // no code
