@@ -153,9 +153,14 @@ Plotter::Plotter()
   bottom(0.0),
   left(0.0),
   right(0.0),
-  areaSelection(false)
+  areaSelection(false),
+  backgroundColor(1,1,1,Lum::OS::Display::whiteColor),
+  gridAColor(0.5,0.5,0.5,Lum::OS::Display::graphScaleColor),
+  gridBColor(0.7,0.7,0.7,Lum::OS::Display::graphScaleColor),
+  axisColor(1,0,0,Lum::OS::Display::blackColor),
+  lineColor(0,0,0,Lum::OS::Display::blackColor)
 {
-  SetBackground(new Lum::OS::PlainFill(Lum::OS::display->GetColor(Lum::OS::Display::whiteColor)));
+  SetBackground(Lum::OS::display->GetFill(Lum::OS::Display::boxedBackgroundFillIndex));
 }
 
 Plotter::~Plotter()
@@ -221,6 +226,10 @@ void Plotter::Draw(int x, int y, size_t w, size_t h)
   double            a,b,startStep,endStep;
   int               count;
 
+  draw->PushForeground(backgroundColor);
+  draw->FillRectangle(this->x,this->y,width,height);
+  draw->PopForeground();
+
   // Now check if we need to calculate some value again
 
   for (size_t f=1; f<=model->GetRows(); f++) {
@@ -300,12 +309,12 @@ void Plotter::Draw(int x, int y, size_t w, size_t h)
 
 
         if (count<=2) {
-          draw->PushForeground(Lum::OS::Display::graphScaleColor); // halfShine
+          draw->PushForeground(gridAColor); // halfShine
           draw->DrawLine(this->x+i,this->y,this->x+i,this->y+this->height-1);
           draw->PopForeground();
         }
         else {
-          draw->PushForeground(Lum::OS::Display::graphScaleColor); // shine
+          draw->PushForeground(gridBColor); // shine
           draw->DrawLine(this->x+i,this->y,this->x+i,this->y+this->height-1);
           draw->PopForeground();
         }
@@ -385,12 +394,12 @@ void Plotter::Draw(int x, int y, size_t w, size_t h)
         }
 
         if (count<=2) {
-          draw->PushForeground(Lum::OS::Display::graphScaleColor); // halfShine
+          draw->PushForeground(gridAColor); // halfShine
           draw->DrawLine(this->x,this->y+i,this->x+width-1,this->y+i);
           draw->PopForeground();
         }
         else {
-          draw->PushForeground(Lum::OS::Display::graphScaleColor); // shine
+          draw->PushForeground(gridBColor); // shine
           draw->DrawLine(this->x,this->y+i,this->x+width-1,this->y+i);
           draw->PopForeground();
         }
@@ -398,7 +407,7 @@ void Plotter::Draw(int x, int y, size_t w, size_t h)
       c+=step;
     }
 
-                 // Labeling of axis
+    // Labeling of axis
     if ((startStep!=endStep && count==2) || (startStep==endStep && count==1)) {
       std::wstring label;
 
@@ -459,7 +468,7 @@ void Plotter::Draw(int x, int y, size_t w, size_t h)
 
   // Draw X-Axis
 
-  draw->PushForeground(Lum::OS::Display::blackColor);
+  draw->PushForeground(axisColor);
   if (top>=0 && bottom<=0) {
     int i=TransformY(0.0);
     draw->DrawLine(this->x,this->y+i,this->x+width-1,this->y+i);
@@ -477,7 +486,7 @@ void Plotter::Draw(int x, int y, size_t w, size_t h)
   // Draw data
 
   draw->PushClip(this->x,this->y,this->width,this->height);
-  draw->PushForeground(Lum::OS::Display::blackColor);
+  draw->PushForeground(lineColor);
 
   for (size_t f=1; f<=model->GetRows(); f++) {
     std::vector<double> &values(model->GetValue(f));
